Online documentation system — CubicWeb 3.13.2

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »
- Web side development »
- The View system »

# Online documentation system

inline help system, using ReST file in products wdoc directory

## Help views

class `cubicweb.web.views.wdoc.` `InlineHelpView`(req=None, rset=None, **kwargs)

class `cubicweb.web.views.wdoc.` `ChangeLogView`(req=None, rset=None, **kwargs)

## Actions

class `cubicweb.web.views.wdoc.` `HelpAction`(req, **extra)

class `cubicweb.web.views.wdoc.` `ChangeLogAction`(req, **extra)

class `cubicweb.web.views.wdoc.` `AboutAction`(req, **extra)

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »
- Web side development »
- The View system »